% Launch Van der Pol problem
%
%    DAE for a forced van der pol model ( u' = v // v' + (mu1 + mu2 u - u^2) v + u = F cos(lambda t) )  (nz=2)
%
% The derivated terms should be with a -1 sign and the forced term is
% isolated on the right hand side, as follows :
%
%    v                    - u'  = 0
%  - u              - rv  - v'  = - F cos(lambda t)
%  mu1 - r - mu2*u  - u^2       = 0
%
%    z(t) = [ u(t) ; v(t) ; r(t) ]  (nz_tot=3)  % unknown of the DAE
%
%    ^
%    u = [ u_0 ;  u_C1 ;  u_C2 ; ...  ; u_CH ; u_S1 ;  u_S2 ; ...  ; u_SH ]  Fourier coef (colum) vector for u
%
%          ^   ^     ^
%    Z= [ u , v , r ]  matrix of unknown Fourier coefficients
%
%    Z= reshape(Z, nz_tot*(2*H+1),1)  -> column vector of unknown Fourier coefficients

global U Ut    % Global variables to export point from the diagram.

addpath('../../SRC')

%% Parameters of the system
nz= 2;     % number of main equations of the DAE system
nz_aux =1;  % number of auxiliary equations of the DAE system
H = 10;     % number of harmonics

% specific parameters
parameters.mu1 = 0.1;
parameters.mu2 = 0.1;
parameters.F   = 1;

%% initialization of the system
%sys=SystHBQ(nz,nz_aux,H,@equations,@point_display,@global_display,parameters,'forced');
sys=SystHBQ_QP(nz,nz_aux,H,@equations,@point_display,@global_display,parameters,'forced');

%% starting point
%
% load('U0_H2_l275');
% [Z0,omega1,omega2,lambda] = sys.init_Hdiff(U0);
% U0 = sys.init_U0(Z0,omega1,omega2,lambda);


% Z0  =randn(2*H+1,sys.nz_tot)*1e-7;
% omega = 0.3; lambda=omega;
% Z0(2,1) = .1;
% U0 = sys.init_U0(Z0,omega,lambda);

% %% From a NS bifurcation
% load('Section_NS_H10');
% U0 = sys.init_NS(Section);
% 
% U0 = U0+randn(size(U0))*1e-5;

load('U_H5_QP');
[Znew,omega1,omega2,lambda] = sys.init_Hdiff(U);
U0 = sys.init_U0(Znew,omega1,omega2,lambda);

%% Launch of Manlab with options
Manlab('sys'       ,sys , ...
    'U0value'         ,U0, ...
    'ANMthreshold'    ,1e-8 , ...
    'NRthreshold'     ,1e-5, ...
    'StabilityCheck'  ,strcmp(sys.type,'HBQ'), ...
    'displayvariables',[ sys.neq+1  2 ;  sys.neq+1 2+H+H ]);     % MANLAB run
%                         lambda   uc1w2   lambda   uc1w1

%% Partir d'un point de New_MAN_QP
% load('V0_H2_l275');
% omega1 = V0(1);
% omega2 = V0(2);
% lambda = V0(end);
% Hold=2;
% Z0compl = reshape(V0(3:end-1),sys.nz_tot,2*Hold*(Hold+1)+1);
% Z0real = sys.compl_to_real(conj(Z0compl'));
% Z0 = Z0real;
%U0real = Z0real(:);
%U0 = [U0real(1:sys.neq-2);omega1;omega2;lambda;U0real(sys.neq-1:end);omega1^2;omega2^2;omega1*omega2;lambda*omega1;lambda*omega2];
%

