%
% Bratu problem
% 
% Bratu continuous equations:
%   find U(x)=(u(x),lambda)) such that
%   u(x)'' + lambda exp(u(x)) = 0 in (0,1), u(0)=u(1)=0.
%
% Bratu discrete equations: 
% Interval (0,1) is divided into N+1 element -> N+2 node at 0 x1 x2   ... xN  1
% the unknowns are u1=u(x1),u2=u(x2), ... uN=u(xN)
% Laplacian is discretized using a central finite difference scheme
% 
%     -2u1 + u2                        + lambda exp(u1) =0
%       u1 -2u2 + u3                   + lambda exp(u2) =0
%                  ...
%                      u{N-2} -2u{N-1} + uN    + lambda exp(u{N-1}) =0
%                               u{N-1} -2uN    + lambda exp(uN)     =0
%
%   As u0 = u(0) = 0 and u{N+1}=u(1) = 0, the bordering terms are not needed
%   in the scheme above.
%
%  In vector form  A.u + lambda exp(u)=0
%
% The unknown vector is U=(u1,...uN,lambda)=(u,lambda)
%
%  Auxiliary variables : vi=exp(ui)   i=1..N
%
%  quadratic expressions
%
%   A.u + lambda v = 0
%   v   - exp(u)   = 0   and    dv - v*du =0 
%

global U Section Diagram    % Global variables to export point from the diagram. 

addpath('../../SRC')

%% Parameters of the system
N=20;
neq = N;
neq_aux = N;

% Specific parameters

A=ones(N,1)*(N+1)^2; % Diagonal vector (with terms 1/dx^2)
K=spdiags([A -2*A A],-1:1,N,N); % Laplacien 1D DFC2 : centered scheme with3 points (1 -2 1)/dx^2

parameters.N=N;
parameters.K=K;

%% initialization of the system

eq = @equations; % Standard initialization of the system.
eq = @equations_vec; % Vectorial initialization of the system. [faster but requires a vectorial writing of the equations]

sys=SystAQ(neq,neq_aux,eq,@point_display,@global_display,parameters);

%% starting point
lambda = 0; 
u0 = zeros(N,1);
v0 = exp(u0);

U0tot = [u0 ; lambda ; v0];

% The bifurcation diagram represents u{N/2} = u(1/2) 
% with respect to lambda :
dispvars = [neq+1 N/2];

%% Launch Manlab
Manlab('sys'            ,sys , ...      
         'U0value'         ,U0tot, ...
         'displayvariables',dispvars);     % MANLAB run

