function [Rtot,dRaux] = equations(sys,Utot,dUtot)
% Quadratic system of the form R(U) = C + L(U) + Q(U,U)

u = Utot(1:sys.neq);         % x,y
lambda = Utot(sys.neq+1);    % lambda
Uaux = Utot(sys.neq+2:end);  % v,r

R = zeros(sys.neq,1);
Raux = zeros(sys.neq_aux,1);
dRaux = zeros(sys.neq_aux,1);

alpha = sys.parameters.alpha;

% Auxiliary variables
%     0 = v - lambda y
%     0 = r - 1 + x^2
Raux(1) = Uaux(1) - lambda*u(2);
Raux(2) = Uaux(2) - 1 + u(1)^2 ;

% Equations of the system
%  0 = y
%  0 = -alpha y + v*r - x
R(1) = u(2);
R(2) = -alpha*u(2) + Uaux(1)*Uaux(2) - u(1);

Rtot = [R;Raux];

end