% Launch exp_tanh example
%
% Equations for exp-tanh example :
%  r1 = u1 + lambda*exp(u2)/(1+u1)   = 0
%  r2 = u2 + u1*tanh(-5u1/(1+u1*u2)) = 0
%
%   U=[ u1 u2 lambda v1 v2 v3 v4 v5 v6]
%
%   r1   =  0  +   u1   +  lambda*v6                = 0
%   r2   =  0  +   u2   +  u1*v3                    = 0
%  raux1 = -1  +   v1   -  u1*u2                    = 0
%  raux2 =  0  +  5u1   +  v1*v2                    = 0
%  raux3 =  0  +   v3   +              -   tanh(v2) = 0
%  raux4 = -1  +   v4   +  v3*v3                    = 0
%  raux5 =  0  +   v5   +              -   exp (u2) = 0
%  raux6 =  0  +  v6-v5 +  u1*v6                    = 0

global U Section Diagram    % Global variables to export point from the diagram. 

addpath('../../SRC')

%% parameters of the system
neq = 2;
neq_aux = 6;

parameters = struct(); % no specific parameters.

%% initialization of the system
sys=SystAQ(neq,neq_aux,@equations,@point_display,@global_display,parameters);

%% starting point
u1 = 0;
u2 = 0;
lambda = 0;

%%% Auxiliary variables :
v1 = 1 + u1*u2;
v2 = -5*u1/v1;
v3 = tanh(v2);
v4 = 1+v3^2;
v5 = exp(u2);
v6 = v5/(1+u1);

U0tot = [u1 u2 lambda v1 v2 v3 v4 v5 v6]'; 

% The bifurcation diagram represents 
% u1 with respect to lambda and
% u2 with respect to lambda :
dispvars = [neq+1 1; ...
            neq+1 2];

%% Launch Manlab
Manlab('sys'             ,sys, ...      
       'U0value'         ,U0tot, ...
       'displayvariables',dispvars);     % MANLAB run

