function [Rtot,dRaux,Forcing] = equations(sys,t,Utot,dUtot,d2Utot)
 
%    DAE for a forced van der pol model ( u' = u // v' + (mu1 + mu2 u - u^2) v + u = F cos(lambda t) )  (nz=2)
%
% The derivated terms should be with a -1 and the forcing term is
% isolated on the right hand side, as follows :
%
%    y                    - x'  = 0
%  - x              + ry  - y'  = - F cos(lambda t)
%  mu1 - r - mu2*x  - x^2       = 0

%%% parameters of the system
mu1 = sys.parameters.mu1;
mu2 = sys.parameters.mu2;
F = sys.parameters.F;

%%% variables of the system
x = Utot(1);dx=dUtot(1);
y = Utot(2);dy=dUtot(2);
r = Utot(3);
lambda = Utot(end);

%%% Auxiliary equations
Raux = zeros(sys.nz_aux,1);     dRaux = zeros(sys.nz_aux,1);
Raux(1) = mu1 - r - mu2*x - x^2;

%%% Physical equations
R = zeros(sys.nz,1);
R(1) = y - dx;
R(2) = - x + y*r - dy;

%%% All the equations of the quadratic system
Rtot = [R;Raux];

%% Forcing terms
% Should be written as if the forcing pulsation value is 1
% i.e. the forcing period value is 2*pi
Forcing = zeros(2*sys.H+1,sys.nz_tot);
Forcing(:,2) = -F*cos(t);

end