function [Rtot,dRaux,Forcing] = equations(sys,t,Utot,dUtot,d2Utot)
% Equations of the system of the form R(U) = C + L(U) + Q(U,U).
% The residu that defines auxiliar variables is computed and then the
% real residu of the system.

u = Utot(1:sys.nz);         % x,y
du = dUtot(1:sys.nz);         % x',y'
Uaux = Utot(sys.nz+1:end-1);  % v,r

lambda = Utot(end);    % lambda

R = zeros(sys.nz,1);
Raux = zeros(sys.nz_aux,1);
dRaux = zeros(sys.nz_aux,1);

alpha = sys.parameters.alpha;

% Auxiliary variables
%     0 = v - lambda y
%     0 = r - 1 + x^2
Raux(1) = Uaux(1) -lambda*u(2);
Raux(2) = Uaux(2) -1 + u(1)^2 ;

% Equations of the system
%  0 = y - x'
%  0 = -alpha y + v*r - x - y'
R(1) = u(2) - du(1);
R(2) = -alpha*u(2) + Uaux(1)*Uaux(2) - u(1) - du(2);

Rtot = [R;Raux];

%%% No forcing :
Forcing = zeros(2*sys.H+1,sys.nz_tot);

end